// desklets - the base .desklet selector is for 'undecorated' desklets however some subtle background themeing is desirable
// to maintain visibility irrespctive of wallpaper and to allow for the highlighting scheme to work
.desklet {
    font-size: 0.9em;
    padding: 8px;
    color: $dark_fg_color;
    border-radius: $roundness;
    background-color: $dark_bg_color_trans;
    &:highlight {
        background-color: $selected_bg_color;
    }
}
// these do not inherit from .desklet
.desklet-with-borders {
    @extend %desklet-shared;

    font-size: 0.9em;
    border-radius: $roundness;
    &:highlight {
        background-color: $selected_bg_color;
    }
}
.desklet-with-borders-and-header {
    @extend %desklet-shared;

    font-size: 0.9em;
    border-radius-bottomleft: $roundness;
    border-radius-bottomright: $roundness;
    &:highlight {
        background-color: $selected_bg_color;
    }
}
.desklet-header {
    @extend %desklet-shared;

    font-size: 1.2em;
    border-radius-topleft: $roundness;
    border-radius-topright: $roundness;
    &:highlight {
        background-color: $selected_bg_color;
    }
}
.photoframe-box {
    @extend %desklet-shared;

    border-radius: $roundness;
    &:highlight {
        background-color: $selected_bg_color;
    }
}
.desklet-drag-placeholder {
    border: 2px solid $selected_bg_color;
    background-color: $dark_bg_color_trans;
    border-radius: $roundness;
}
.launcher {
    padding: 1px;
    transition-duration: 150;
    .icon-box {
        padding-top: 2px;
    }
}
// inherits font characteristics from .desklet-header
.clock-desklet-label {
}
