/****************
 ! Gnome clocks *
*****************/

@include exports("gnome-clocks") {
    .clocks-analog-frame {
        &.trough { color: mix($fg_color, $bg_color, .85); }

        &.progress { color: mix($bg_color, $selected_bg_color, .5); }

        &.progress-fast { color: shade($selected_bg_color, .7); }
    }
}


/*****************
 ! Gnome Builder *
******************/

@include exports("gnome-builder") {
    workbench.csd > stack.titlebar:not(headerbar) {
        padding: 0;
        background: none;
        border: 0;
        box-shadow: none;

        headerbar {
            &, &:first-child, &:last-child { border-radius: $roundness $roundness 0 0; }
        }
    }
}


/****************
 ! Geary *
*****************/

@include exports("geary") {
    .geary-expanded .geary-message-summary {
        background-color: shade($base_color, .95);
    }

    .geary-folder-popover-list-row {
        border-color: shade($menu_bg_color, 1.2);
        box-shadow: None;

        > label { color: $bg_color; }
    }

}
