/******************
 ! Budgie Desktop *
*******************/

@include exports("budgie-desktop") {
    .budgie-container {
        background-color: transparent;
    }

    .raven {
        background-color: transparentize($bg_color, .07);

        .raven-header {
            background-color: $bg_color;
            border: solid $borders_color;
            border-width: 1px 0;
        }

        .raven-background {
            background-color: transparentize($bg_color, .07);
        }
    }

    .raven-mpris {
        background-color: transparentize($bg_color, .3);
    }
}
