@import "panel";

/****************
 ! Unity styles *
*****************/

@include exports("unity") {
    UnityDecoration {
        -UnityDecoration-extents: 28px 1px 1px 1px;
        -UnityDecoration-input-extents: 10px;

        -UnityDecoration-shadow-offset-x: 1px;
        -UnityDecoration-shadow-offset-y: 1px;
        -UnityDecoration-active-shadow-color: rgba(0, 0, 0, .7);
        -UnityDecoration-active-shadow-radius: 8px;
        -UnityDecoration-inactive-shadow-color: rgba(0, 0, 0, .5);
        -UnityDecoration-inactive-shadow-radius: 5px;

        -UnityDecoration-glow-size: 10px;
        -UnityDecoration-glow-color: $selected_bg_color;

        -UnityDecoration-title-indent: 10px;
        -UnityDecoration-title-fade: 35px;
        -UnityDecoration-title-alignment: 0;


        &.top {
            border: 1px solid mix(shade($titlebar_bg_focused, 0.7), $titlebar_fg_focused, 0.21);
            border-bottom: 0;
            border-radius: 2px 2px 0 0;
            padding: 1px 8px 0 8px;
            background-color: $titlebar_bg_focused;
            color: $titlebar_fg_focused;
            text-shadow: none;

            &:backdrop {
                border: 1px solid mix(shade($titlebar_bg_unfocused, 0.7), $titlebar_fg_unfocused, 0.12);
                border-bottom: 0;
                background-color: $titlebar_bg_unfocused;
                color: $titlebar_fg_unfocused;
            }
        }

        &.left, &.right, &.bottom {
            background-color: mix(shade($titlebar_bg_focused, 0.7), $titlebar_fg_focused, 0.21);

            &:backdrop { 
               background-color: mix(shade($titlebar_bg_unfocused, 0.7), $titlebar_fg_unfocused, 0.12);
            }
        }
    }

    UnityPanelWidget, .unity-panel {
        @extend %panel;

        border: 0;
    }

    .unity-panel {
        &.menuitem, .menuitem {
            border-width: 0 1px;
            color: $panel_fg_color;

            &:hover, *:hover {
                border-color: mix($panel_bg_color, $panel_fg_color, .21);
                background-color: mix($panel_bg_color, $panel_fg_color, .21);
                background-image: none;
                color: shade($panel_fg_color, 1.08);
            }
        }
    }

    SheetStyleDialog.unity-force-quit { background-color: $bg_color; }
}
