/**********
 ! Calendar
***********/

@include exports("calendar") {
    GtkCalendar {
        padding: 1px 3px;
        outline-offset: -1px;

        &:inconsistent { color: mix($fg_color, $bg_color, .5); }

        &.view, &.highlight, &.header, &.button {
            &, &:focus, &:hover, &:insensitive {
                background-color: transparent;
                background-image: none;
                border-width: 0;
                border-radius: 0;
            }
        }

        &.button {
            &, &:focus, &:hover, &:insensitive {
                color: $white;
                border-width: 0;
                box-shadow: none;
            }
        }

        &.highlight { color: $selected_bg_color; }
    }

    /* gnome-calendar */
    .calendar-view {
        background-color: $base_color;
        color: $text_color;
    }
}

