/*********
 ! Sidebar
**********/

@include exports("sidebar") {
    .sidebar {
        &, &.view, .view, GtkScrolledWindow {
            background-color: $bg_color;
            color: mix($fg_color, $bg_color, .1);

            &.separator {
                &, &:hover, &:focus {
                    border-width: 1px;
                    border-style: solid;
                    border-color: shade($bg_color, .9);
                    color: shade($bg_color, .9);
                }
            }
        }

        row, .view row {
            &:selected {
                &, &:hover, &:focus {
                    border: 0;
                    background-image: none;
                    background-color: $selected_bg_color;
                    color: $selected_fg_color;
                }

                &:hover {
                    border: 0;
                    background-image: none;
                    background-color: shade($selected_bg_color, 1.05);
                    color: $selected_fg_color;
                }
            }

            &:hover {
                border: 0;
                background-image: none;
                background-color: shade($bg_color, 1.05);
            }
        }

        .frame { border-width: 0; }

        .sidebar-row {
            padding: 1px;
        }

        .sidebar-icon {
              padding-left: $spacing * 2;
              padding-right: $spacing * 2;
        }

        GtkAssistant & {
            padding: $spacing;
            border-width: 0 1px 0 0;
            border-style: solid;
            border-right-color: border_normal($bg_color);
            border-radius: 0;
            background-color: $bg_color;
            color: mix($fg_color, $bg_color, .1);

            &:dir(ltr) { border-width: 0 1px 0 0; }

            &:dir(rtl) { border-width: 0 0 0 1px; }

            .label {
                padding: $spacing ($spacing * 2);

                &.highlight { background-color: mix($bg_color, $fg_color, .8); }
            }

            &.csd .sidebar { border-top-style: none; }

            .highlight { font: bold; }
        }
    }
}


/******
! Paned
*******/

@include exports("paned") {
    GtkPaned {
        -GtkPaned-handle-size: 1;
        -gtk-icon-source: none;
        margin: 0 $spacing;

        &:dir(rtl) {
            margin-right: 0;
            margin-left: $spacing;
        }

        .pane-separator { background-color: shade($bg_color, .9); }

        &.wide {
            -GtkPaned-handle-size: 4;
            margin: 0;

            .pane-separator {
                background-color: transparent;
                border-style: none solid;
                border-color: shade($bg_color, .9);
                border-width: 1px;
            }

            &.vertical .pane-separator { border-style: solid none; }
        }
    }
}
