// notification system
#notification {
    @extend %bg-grad-to-right;

    border-radius: $roundness;
    border: 1px solid $exterior_border;
    padding: 8px;
    spacing-rows: 5px;
    spacing-columns: 10px;
    margin-from-right-edge-of-screen: 20px;
    width: 34em;
    color: $dark_fg_color;
    &.multi-line-notification {
        padding-bottom: 8px;
        color: $dark_fg_color;
    }
    StEntry {
        @extend %dialog-entry;

        &:focus {
            border: 1px solid $selected_border;
        }
    }
    .url-highlighter {
        link-color: $link_color;
    }
}
.notification-with-image {
    min-height: 159px;
    color: $dark_fg_color;
}
#notification-scrollview {
    max-height: 10em;
    > {
        .top-shadow {
            height: 1em;
        }
        .bottom-shadow {
            height: 1em;
        }
    }
    &:ltr > StScrollBar {
        padding-left: 6px;
    }
    &:rtl > StScrollBar {
        padding-right: 6px;
    }
}
#notification-body {
    spacing: 4px;
}
#notification-actions {
    spacing: 8px;
}
.notification-button {
    @extend %shared-button;

    border-radius: $roundness;
    min-width: 5em;
    min-height: 1em;
    padding: $spacing_plus2;
    &:hover {
        @extend %shared-button-hover;
    }
    &:focus {
        color: $selected_fg_color;
    }
    &:active {
        @extend %shared-button-active;
    }
}
.notification-icon-button {
    @extend %shared-button;

    border-radius: $roundness;
    min-width: 2em;
    min-height: 2em;
    padding: $spacing_plus2;
    &:hover {
        @extend %shared-button-hover;
    }
    &:focus {
        color: $selected_fg_color;
    }
    &:active {
        @extend %shared-button-active;
    }
    > StIcon {
        icon-size: 1.5em;
    }
}
