// scss-lint:disable ColorVariable

@import "functions";

// default color scheme
$bg_color: if($variant == "dark", #%FG%, #%BG%);
$fg_color: if($variant == "dark", #%BG%, #%FG%);
$base_color: if($variant == "dark", #%TXT_FG%, #%TXT_BG%);
$text_color: if($variant == "dark", #%TXT_BG%, #%TXT_FG%);
$button_bg_color: if($variant == "dark", #%BTN_FG%, #%BTN_BG%);
$button_fg_color: if($variant == "dark", #%BTN_BG%, #%BTN_FG%);
$header_button_bg_color: #%HDR_BTN_BG%;
$header_button_fg_color: #%HDR_BTN_FG%;
$selected_bg_color: #%SEL_BG%;
$selected_fg_color: #%SEL_FG%;
$tooltip_bg_color: #%BG%;
$tooltip_fg_color: #%FG%;

// dark colors
$dark_bg_color: #%MENU_BG%;
$dark_fg_color: #%MENU_FG%;

// shadows
/*$dark_shadow: #000;*/
/*$light_shadow: #fff;*/
$dark_shadow: shade($fg_color, .2);
$light_shadow: lighten($bg_color, .4);

// caret
$primary_caret_color: #%CARET1_FG%;
$secondary_caret_color: #%CARET2_FG%;
$caret_aspect_ratio: %CARET_SIZE%;

// white and black
//$black: #000;
//$white: #fff;
$black: shade($fg_color, .4);
$white: lighten($bg_color, .55);

//$link_color: mix($selected_bg_color, $fg_color, .3);
$link_color: #%TERMINAL_COLOR4%;
$success_color: #%TERMINAL_COLOR10%;
$warning_color: #%TERMINAL_COLOR11%;
$error_color: #%TERMINAL_COLOR9%;

$info_fg_color: #%TERMINAL_BACKGROUND%;
$info_bg_color: #%TERMINAL_COLOR12%;
$warning_fg_color: #%TERMINAL_BACKGROUND%;
$warning_bg_color: $warning_color;
$question_fg_color: #%TERMINAL_BACKGROUND%;
$question_bg_color: $info_bg_color;
$error_fg_color: #%TERMINAL_BACKGROUND%;
$error_bg_color: $error_color;

$toolbar_bg_color: $bg_color;
$toolbar_fg_color: $fg_color;

$titlebar_bg_focused: $dark_bg_color;
$titlebar_bg_unfocused: $bg_color;
$titlebar_fg_focused: $dark_fg_color;
$titlebar_fg_unfocused: mix($fg_color, $bg_color, .4);

$menu_bg_color: $dark_bg_color;
$menu_fg_color: $dark_fg_color;

$menubar_bg_color: $dark_bg_color;
$menubar_fg_color: $dark_fg_color;

$panel_bg_color: $dark_bg_color;
$panel_fg_color: $dark_fg_color;

$osd_base: $dark_bg_color;
$osd_fg: $dark_fg_color;
$osd_bg: alpha($osd_base, 0.8);

$lightdm_bg_color: $dark_bg_color;
$lightdm_fg_color: $dark_fg_color;

$wm_bg_focused: $titlebar_bg_focused;
$wm_bg_unfocused: $titlebar_bg_unfocused;
$wm_border_focused: #%WM_BORDER_FOCUS%;
$wm_border_unfocused: #%WM_BORDER_UNFOCUS%;
$wm_title_focused: $titlebar_fg_focused;
$wm_title_unfocused: $titlebar_fg_unfocused;
$wm_icons_focused: $titlebar_fg_focused;
$wm_icons_focused_prelight: $selected_bg_color;
$wm_icons_focused_pressed: shade($selected_bg_color, .8);
$wm_icons_unfocused: $titlebar_fg_unfocused;
$wm_icons_unfocused_prelight: $selected_bg_color;
$wm_icons_unfocused_pressed: shade($selected_bg_color, .8);

// widget styles
$roundness: %ROUNDNESS%px;
$spacing: %SPACING%px;
$gradient: %GRADIENT%;

$contrast: .8;
