@import "panel";

/***************
 ! Xfce styles *
****************/

@include exports("xfce") {
    .XfceHeading {
        margin: 0;
        padding: 0;
        border: 0;
        background-image: none;
        background-color: $base_color;
        color: $text_color;
    }

    .xfce4-panel {
        @extend %panel;

        font: inherit;

        button { @extend %panelbutton; }

        menu {
            -gtk-icon-effect: none;

            text-shadow: none;
        }
    }
}
