// non 3D alt-tab options
#altTabPopup {
    padding: 8px;
    spacing: 16px;
}
.switcher-list {
    @extend %bg-grad-to-bottom;

    border-radius: $roundness;
    border: 1px solid $exterior_border;
    padding: 16px;
    color: $dark_fg_color;
    .item-box {
        padding: 8px;
        border-radius: $roundness;
        &:selected {
            @extend %selected-bg-grad-to-bottom;

            color: $selected_fg_color;
        }
    }
    .thumbnail-box {
        padding: 2px;
        spacing: 4px;
        color: $dark_fg_color;
    }
    .thumbnail {
        min-width: 20em;
    }
    .separator {
        width: 1px;
        background-color: $selected_bg_color;
    }
}
.switcher-list-item-container {
    spacing: 8px;
}
.thumbnail-scroll-gradient-left {
    background-gradient-direction: horizontal;
    background-gradient-start: rgba(51, 51, 51, 1.0);
    background-gradient-end: rgba(51, 51, 51, 0);
    border-radius: $roundness;
    border-radius-topright: 0;
    border-radius-bottomright: 0;
    width: 60px;
}
.thumbnail-scroll-gradient-right {
    background-gradient-direction: horizontal;
    background-gradient-start: rgba(51, 51, 51, 0);
    background-gradient-end: rgba(51, 51, 51, 1.0);
    border-radius: $roundness;
    border-radius-topleft: 0;
    border-radius-bottomleft: 0;
    width: 60px;
}
.switcher-arrow {
    border-color: rgba(0,0,0,0);
    color: $dark_fg_color;
    &:highlighted {
        border-color: rgba(0,0,0,0);
        color: $selected_fg_color;
    }
}
.switcher-preview-backdrop {
    background-color: rgba(25,25,25,0.65);
}
