// defines font family and standard font size across the whole theme
// em is preferred for better support for text scaling
stage {
    font-family: roboto, Noto Sans, sans, sans-serif;
    font-size: 1em;
}
.cinnamon-link {
    color: $link_color;
    font-style: italic;
    &:hover {
        color: $selected_fg_color;
    }
}
.label-shadow {
    color: rgba(0,0,0,0.5);
}
// themeing for various standard elements
StScrollBar {
    padding: 2px;
    StButton {
        &#vhandle {
            background-color: $scrollbar_slider_color;
            border-radius: $roundness;
            &:hover {
                background-color: $scrollbar_slider_hover_color;
            }
        }
        &#hhandle {
            background-color: $scrollbar_slider_color;
            border-radius: $roundness;
            &:hover {
                background-color: $scrollbar_slider_hover_color;
            }
        }
    }
    StBin#trough {
        background-color: $scrollbar_bg_color;
        border-radius: $roundness;
    }
}
StScrollView {
    &.vfade {
        -st-vfade-offset: 68px;
    }
    &.hfade {
        -st-hfade-offset: 68px;
    }
    StScrollBar {
        min-width: 0.8em;
        min-height: 0.8em;
    }
}
.separator {
    @extend %separator-shared;
}
.slider {
    @extend %slider-shared;
}
.check-box {
    CinnamonGenericContainer {
        spacing: .2em;
    }
    StBin {
        @extend %check-box-shared;
    }
    &:focus {
        StBin {
            @extend %check-box-shared;
        }
        &:checked StBin {
            background-image: url(assets/checkbox.svg);
        }
    }
    StLabel {
        font-weight: normal;
    }
    &:checked StBin {
        background-image: url(assets/checkbox.svg);
    }
}
.radiobutton {
    CinnamonGenericContainer {
        spacing: .2em;
        height: 18px;
        padding-top: 2px;
    }
    StBin {
        @extend %radiobutton-shared;
    }
    &:focus {
        StBin {
            @extend %radiobutton-shared;
        }
        &:checked StBin {
            background-image: url(assets/radiobutton.svg);
        }
    }
    StLabel {
        padding-top: 4px;
        font-size: 0.8em;
        box-shadow: none;
    }
    &:checked StBin {
        background-image: url(assets/radiobutton.svg);
    }
}
#Tooltip {
    @extend %tooltip-bg-grad-to-top;

    padding: 5px 8px;
    color: $tooltip_fg_color;
    text-align: center;
    border-radius: $roundness;
}
