@import "button";


/*********
 ! Infobar
**********/

@include exports("infobar") {
    infobar {
        border: 0;

        $types: (
            info: ($info_fg_color, $info_bg_color),
            warning: ($warning_fg_color, $warning_bg_color),
            question: ($question_fg_color, $question_bg_color),
            error: ($error_fg_color, $error_bg_color),
        );

        @each $type, $colors in $types {
            $fg_color: nth($colors, 1);
            $bg_color: nth($colors, 2);

            &.#{$type} {
                &, &:backdrop { // Backdrop button fix: https://github.com/numixproject/numix-gtk-theme/issues/544
                    @include linear-gradient($bg_color);

                    border: 1px solid shade($bg_color, .8);
                    caret-color: currentColor;

                    label, & { color: $fg_color; }
                }

                button {
                    @include button($bg_color, $fg_color);

                    &.close { @extend %close_button; }
                }
            }
        }
    }
}
