// on screen preview of windows tiling placement
.tile-preview {
    @extend %tile-shared;

    &.snap {
        @extend %tile-shared-snap;
    }
}
.tile-hud {
    @extend %tile-shared;

    &.snap {
        @extend %tile-shared-snap;
    }
    &:top {
        border-top-width: 0;

        border-radius: 0 0 10px 10px;
    }
    &:bottom {
        border-bottom-width: 0;

        border-radius: $roundness $roundness 0 0;
    }
    &:left {
        border-left-width: 0;

        border-radius: 0 10px 10px 0;
    }
    &:right {
        border-right-width: 0;

        border-radius: 10px 0 0 10px;
    }
    &:top-left {
        border-top-width: 0;
        border-left-width: 0;

        border-radius: 0 0 10px 0;
    }
    &:top-right {
        border-top-width: 0;
        border-right-width: 0;

        border-radius: 0 0 0 10px;
    }
    &:bottom-left {
        border-bottom-width: 0;
        border-left-width: 0;

        border-radius: 0 10px 0 0;
    }
    &:bottom-right {
        border-bottom-width: 0;
        border-right-width: 0;

        border-radius: 10px 0 0 0;
    }
}
