/**************
 ! Window frame
***************/

@include exports("window") {
    decoration {
        @include linear-gradient($dark_bg_color);

        $_wm_border: transparentize($wm_border_unfocused, .77);

        border-radius: $roundness $roundness 0 0;
        // lamefun trick to get rounded borders regardless of CSD use
        //border-width: 0;

        box-shadow: 0 3px 9px 1px transparentize($black, .3), 0 0 0 1px $wm_border_focused; //doing borders with box-shadow
        /* this is used for the resize cursor area */
        //margin: $spacing * 3;

        border-width: $spacing % 2 or 1px;
        border-style: solid;
        //border-color: $wm_border_focused;
        //@TODO:
        border-color: $wm_border_unfocused;


        &:backdrop {
            box-shadow: 0 3px 9px 1px transparent, 0 2px 6px 2px transparentize($black, .6), 0 0 0 1px $wm_border_unfocused;
            border-color: $wm_border_unfocused;
            transition: 200ms ease-out;
        }

        .maximized &, .fullscreen &, .tiled & { border-radius: 0; }

        .popup & { box-shadow: none; }

        // this needs to be transparent
        // see bug #722563
        // server-side decorations as used by mutter
        // Fixed gtk-3.18 Unity bug (https://github.com/numixproject/numix-gtk-theme/issues/270)
        .ssd & {
            box-shadow: 0 0 0 1px $wm_border_focused;

            &:backdrop {
                box-shadow: 0 0 0 1px $wm_border_unfocused;
            }
        } //just doing borders, wm draws actual shadows

        .solid-csd & {
            border-radius: 0;
            //margin: 1px;
            //background-color: $bg_color;
            // Unity/compiz regression: Issue: https://github.com/numixproject/numix-gtk-theme/issues/206
            box-shadow: none;
        }

        .csd.popup & {
            border-radius: 0;
            box-shadow: 0 1px 2px transparentize($black, .8), 0 0 0 1px transparentize($_wm_border, .1);
        }

        tooltip.csd & {
            border-radius: $roundness;
            box-shadow: none;
        }

        messagedialog.csd & {
            border-radius: $roundness;
            box-shadow: 0 1px 2px transparentize($black, .8), 0 0 0 1px transparentize($_wm_border, .1);
        }
    }
}
