@import "global";

/* dark color scheme */
@define-color dark_bg_color #{"" + $dark_bg_color};
@define-color dark_fg_color #{"" + $dark_fg_color};

/* colormap actually used by the theme, to be overridden in other css files */
@define-color theme_bg_color #{"" + $bg_color};
@define-color theme_fg_color #{"" + $fg_color};
@define-color theme_base_color #{"" + $base_color};
@define-color theme_text_color #{"" + $text_color};
@define-color theme_selected_bg_color #{"" + $selected_bg_color};
@define-color theme_selected_fg_color #{"" + $selected_fg_color};
@define-color theme_tooltip_bg_color #{"" + $tooltip_bg_color};
@define-color theme_tooltip_fg_color #{"" + $tooltip_fg_color};

/* shadow effects */
@define-color light_shadow #{"" + $light_shadow};
@define-color dark_shadow #{"" + $dark_shadow};

/* misc colors used by gtk+ */
@define-color info_fg_color #{"" + $info_fg_color};
@define-color info_bg_color #{"" + $info_bg_color};
@define-color warning_fg_color #{"" + $warning_fg_color};
@define-color warning_bg_color #{"" + $warning_bg_color};
@define-color question_fg_color #{"" + $question_fg_color};
@define-color question_bg_color #{"" + $question_bg_color};
@define-color error_fg_color #{"" + $error_fg_color};
@define-color error_bg_color #{"" + $error_bg_color};
@define-color link_color #{"" + $link_color};
@define-color success_color #{"" + $success_color};
@define-color warning_color #{"" + $warning_color};
@define-color error_color #{"" + $error_color};

/* widget colors */
@define-color titlebar_bg_focused @dark_bg_color;
@define-color titlebar_bg_unfocused @theme_bg_color;
@define-color titlebar_fg_focused @dark_fg_color;
@define-color titlebar_fg_unfocused #{"" + $titlebar_fg_unfocused};
@define-color menubar_bg_color @dark_bg_color;
@define-color menubar_fg_color @dark_fg_color;
@define-color toolbar_bg_color @theme_bg_color;
@define-color toolbar_fg_color @theme_fg_color;
@define-color menu_bg_color @dark_bg_color;
@define-color menu_fg_color @dark_fg_color;
@define-color panel_bg_color @dark_bg_color;
@define-color panel_fg_color @dark_fg_color;

/* osd */
@define-color osd_base #{"" + $osd_base};
@define-color osd_bg #{"" + $osd_bg};
@define-color osd_fg #{"" + $osd_fg};

/* lightdm greeter colors */
@define-color lightdm_bg_color #{"" + $lightdm_bg_color};
@define-color lightdm_fg_color #{"" + $lightdm_fg_color};

/* window manager colors */
@define-color wm_bg_focused #{"" + $wm_bg_focused};
@define-color wm_bg_unfocused #{"" + $wm_bg_unfocused};
@define-color wm_border_focused #{"" + $wm_border_focused};
@define-color wm_border_unfocused #{"" + $wm_border_unfocused};
@define-color wm_title_focused #{"" + $wm_title_focused};
@define-color wm_title_unfocused #{"" + $wm_title_unfocused};
@define-color wm_icons_focused #{"" + $wm_icons_focused};
@define-color wm_icons_focused_prelight #{"" + $wm_icons_focused_prelight};
@define-color wm_icons_focused_pressed #{"" + $wm_icons_unfocused_pressed};
@define-color wm_icons_unfocused #{"" + $wm_icons_unfocused};
@define-color wm_icons_unfocused_prelight #{"" + $wm_icons_unfocused_prelight};
@define-color wm_icons_unfocused_pressed #{"" + $wm_icons_unfocused_pressed};
