/**********************
 ! Genome Terminal *
***********************/

@include exports("gnome-terminal") {
    //noinspection ScssLintInspection,ScssLintInspection
    VteTerminal {
        background-color: $osd_base;
        color: $osd_fg;
    }

    terminal-window {
        junction, scrollbar trough {
            background-color: $osd_base;
            border-color: border_normal($osd_base);

            //&:backdrop {
            //    background-color: shade($backdrop_osd_bg, .9);
            //    border-color: border_normal(shade($backdrop_osd_bg, .9));
            //}
        }

        scrollbar.vertical {
            slider {
                background-color: mix($osd_base, $osd_fg, .2);

                &:hover { background-color: mix($osd_base, $osd_fg, .3); }

                &:hover:active { background-color: $selected_bg_color; }

                //&:backdrop { background-color: mix($backdrop_osd_fg, $backdrop_osd_bg, .4); }

                &:disabled { background-color: transparent; }
            }
        }
    }
}
