/*********************
 ! Cinnamon Settings *
**********************/

@include exports("cinnamon-settings") {
    .cs-category-view {
        &, .view {
            &, &:backdrop {
                background-color: transparent;
            }

            &:selected {
                &:focus, & {
                    @extend %selected_items;
                }
            }
        }
    }
}
