@import "_global";
@import "_extends";

@import "sections/_stage";
@import "sections/_menu";
@import "sections/_panel";
@import "sections/_calendar";
@import "sections/_accessibility";
@import "sections/_notifications";
@import "sections/_dialogs";
@import "sections/_desklets";
@import "sections/_alt-tab";
@import "sections/_overview";
@import "sections/_tile-hud";
